@@ -1,12 +1,12 @@
 package Perinci::Examples::Bin;
 
+our $DATE = '2014-10-30'; # DATE
+our $VERSION = '0.04'; # VERSION
+
 use 5.010001;
 
-our $DATE = '2014-07-03'; # DATE
-our $VERSION = '0.03'; # VERSION
-
 1;
-# ABSTRACT: Perinci example scripts
+# ABSTRACT: Perinci example scripts (using Perinci::CmdLine)
 
 __END__
 
@@ -16,17 +16,17 @@ __END__
 
 =head1 NAME
 
-Perinci::Examples::Bin - Perinci example scripts
+Perinci::Examples::Bin - Perinci example scripts (using Perinci::CmdLine)
 
 =head1 VERSION
 
-This document describes version 0.03 of Perinci::Examples::Bin (from Perl distribution Perinci-Examples-Bin), released on 2014-07-03.
+This document describes version 0.04 of Perinci::Examples::Bin (from Perl distribution Perinci-Examples-Bin), released on 2014-10-30.
 
 =head1 DESCRIPTION
 
-This distribution contains example scripts in bin/. It is split from
-L<Perinci::Examples> so the latter does not need to depend on
-L<Perinci::CmdLine>.
+This distribution contains example scripts in C<bin/> which use
+L<Perinci::CmdLine>. It was split from L<Perinci::Examples> so the latter does
+not need to depend on Perinci::CmdLine.
 
 =head1 HOMEPAGE
 
@@ -34,7 +34,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples-Bin>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples-Bin>.
 
 =head1 BUGS
 
@@ -46,11 +46,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
